@@ -116,6 +116,13 @@ class Icons(gobject.GObject):
     def getSize(self):
 	return(self.size)
 
+    def setWindow(self, win):
+	""" Set the window for all icons """
+
+	for i in self.icons:
+	    ic=self.icons[i]
+	    ic.setWindow(win)
+
     def signalLongpress(self, icon):
 	#print "signalLongpress()", icon
 	self.emit('long-press', icon)
